<template>
    <div class="graph-container">
        <div class="graph-inner" @dblclick="toggleGraph()">
            <div class="graph"></div>
        </div>
        <Modal
            v-model="modal1"
            fullscreen
            footer-hide>
        </Modal>
    </div>
</template>
<script>
import echarts from 'echarts';
import darkColor from '../libs/echarts/theme/dark-color';
import $ from 'jquery';
import {
    getMaxFromArr,      // 从数组中获取最大值
    getMinFromArr       // 从数组中获取最小值
} from '../libs/common';
export default {
    name: 'LineGraph',
    props:{
        unit: {     // 单位
            type: String,
            default: ''
        },
        title: {     // 标题
            type: String,
            default: ''
        },
        subtitle: {
            type: String,
            default: ''
        },
        min: {
            type: [Number, String],
            default: 0
        },
        max: {
            type: [Number, String],
            default: 10
        },
        name: {
            type: [String],
            default: ''
        },
        visualMap:{
            type: [Object, Boolean],
            default: false
        },
        markLine: {
            type: [Object, Boolean],
            default: false
        },
        theme: {
            type: String,
            default:function(theme) {
                var result = 'macarons';
                switch(theme) {
                    case 'dark':
                        result = 'dark';
                    break;
                    case 'vintage':
                        result = 'vintage';
                    break;
                    case 'macarons':
                        result = 'macarons';
                    break;
                    case 'infographic':
                        result = 'infographic';
                    break;
                    case 'shine':
                        result = 'shine';
                    break;
                    case 'roma':
                        result = 'roma';
                    break;
                    case 'dark-color':
                        result="dark-color";
                    break;
                    default:
                        result = 'macarons';
                    break;
                }
                return 'result';
            }
        }
    },
    data: function() {
        var unit = this.unit?'('+this.unit+')':'';
        return {
            modal1: false,
            graphEl: '',
            graph: '',
            option: {
                title: {
                    text: this.title,
                    subtext: this.subtitle,
                    x: 'center',
                },
                tooltip: {
                    trigger: 'axis'
                },
                xAxis: {
                    type: 'category',
                    boundaryGap : false,
                    data:[]
                },
                yAxis: {
                    name: 'y'+unit,
                    type: 'value',
                    min: this.min,
                    max: this.max
                },
                grid: {
                    left: '3%',
                    right: '2%',
                    bottom: '3%',
                    containLabel: true
                },
                visualMap: this.visualMap,
                series: {
                    name: this.name,
                    data: [],
                    type: 'line',
                    smooth: true,
                    markLine: this.markLine
                }
            }
        }
    },
    methods: {
        setOption: function(option, times) {
            this.graph.resize();
            // 是否为第二次加载
            if(times) {
                if(this.option.visualMap) {
                    option.visualMap = this.option.visualMap;
                }

                if(this.option.series.markLine) {
                    option.series.markLine = this.option.series.markLine;
                }
            }
            

            this.option = $.extend({}, this.option, option);
            var min = getMinFromArr(this.option.series.data);
            var max = getMaxFromArr(this.option.series.data);
            this.option.yAxis.min = min>this.min?this.min:min;
            this.option.yAxis.max = max<this.max?this.max:max;
            //console.log(this.option);
            this.graph.setOption(this.option);
        },
        resize: function() {
            this.graph.resize();
            this.graph.setOption(this.option);
        },
        updateLine: function(visualMap, markLine) {
            this.option.visualMap = visualMap;
            this.option.series.markLine = markLine;
            //console.log(this.option);
            this.graph.setOption(this.option);
        },
        getDataURL: function() {
            var result = this.graph.getDataURL({
                type: 'png',
                backgroundColor: '#FFFFFF'
            });

            return result;
        },
        toggleGraph: function() {
            //this.modal1 = this.modal1?false:true;
        }
    },
    mounted: function() {
        echarts.registerTheme('dark-color', darkColor);
        var _self = this;
        var option = this.option;
        var theme = this.theme;
        var $el = $(this.$el);
        var graph = $el.find('.graph').get(0);
        this.graphEl = graph;
        this.graph = echarts.init(graph, theme);
        this.setOption();
    }
}
</script>
<style scoped>
    .graph-inner {
        height: 100%;
    }
    .graph {
        width: 100%;
        height: 100%;
    }
</style>
